@@ -132,7 +132,7 @@ class Storage(driver.Base):
             part_size = self.buffer_size
         
         try:
-            tmp_file = tempfile.mktemp(suffix=path1, prefix=str(uuid.uuid1()), dir="/tmp")
+            tmp_file = tempfile.mktemp(suffix="", prefix=str(uuid.uuid1()), dir="/tmp")
             with open(tmp_file, 'w') as f:
                 while True:
                     buf = fp.read(part_size)
